Learn R Programming

PharmPow (version 1.0)

PharmPow-package: Pharmacometric Power calculations for mixed study designs

Description

This package contains functions performing power calculation for mixed (sparse/dense sampled) pharmacokinetic study designs. The input data for these functions is taylored for NONMEM .phi files.

Arguments

Details

Package:
PharmPow
Type:
Package
Version:
1.0
Date:
2013-09-16
License:
MIT + file LICENSE
PharmPow_parallel PharmPow_crossover fig_PharmPow_parallel fig_PharmPow_crossover